#!/bin/bash
 
# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# last revised : 21/10/2011
#
#package			: sakura
#homepage			: http://www.pleyades.net/david/sakura.php
#source location                : "http://launchpad.net/sakura/trunk/2.4.2/+download/sakura-2.4.2.tar.bz2" "http://zenwalk.pinguix.com/user-accounts/stillborn/sakura/sakura.png"
#dependency: 


set -e -u -x

#> log
(

softname='pcmanfm-mod'
softversion='1.2.3'
zenver='72.1'
arch='i486'
cpu='i686'
numjobs='-j4'

#>

buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.xz"
package="$softname-$softversion-$arch-$zenver"
dest="$buildir/$package"
source="http://downloads.sourceforge.net/project/pcmanfm-mod/pcmanfm-mod-1.2.3.tar.xz"
sourcetemplate="http://zenwalk.pinguix.com/user-accounts/stillborn/pcmanfm-mod"

#>

INS644="install -o root -g root -m 644"
INS755="install -d -o root -g root -m 755"

#>
rm -rfv $dest
rm -fv $package.{txz,src,dep,md5}
$INS755 $dest/{install,usr/{doc/$softname-$softversion,share/icons/hicolor/48x48/apps,src/$softname-$softversion}}

#> prepare slack-desc
cat <<EOF > $dest/install/slack-desc 
           |-----handy-ruler------------------------------------------------------|
$softname: $softname (a fast and lightweight file manager)
$softname:
$softname: $softname file manager is an extremely fast, lightweight, yet
$softname: feature-rich file manager with tabbed browsing.
$softname: This is a modified version of the legacy PCMan File Manager that
$softname: fixes several bugs.
$softname: 
$softname:
$softname:
$softname:
$softname:
EOF

cat << "DOINST" > $dest/install/doinst.sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

# update glib schemas
if [ -x usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas 1> /dev/null 2> /dev/null
fi
DOINST


#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar xf $srcpkg
cd $src	

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

patch -p1 < $buildir/el.patch || exit 1
./configure --prefix=/usr --libdir=/usr/lib --localstatedir=/var --sysconfdir=/etc --disable-static --build=$arch-slackware-linux
make $numjobs 
make install DESTDIR=$dest

#>where you hiding
install -o root -g root -m 755 $src/pcmanfm-opener $buildir/$package/usr/bin
cd $buildir/$package/usr/bin
ln -s pcmanfm-mod pcmanfm

#> prepare icon
$INS644 $src/data/$softname.png $dest/usr/share/icons/hicolor/48x48/apps
$INS644 $src/data/$softname-root.png $dest/usr/share/icons/hicolor/48x48/apps

#> add docs, infos, ...
(cd $src
$INS644 \
      AUTHORS COPYING README* INSTALL NEWS ChangeLog \
$dest/usr/doc/$softname-$softversion
)


#> Strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)


#> store buildscript 
(
cd $buildir
$INS644 build-$softname.sh $dest/usr/src/$softname-$softversion
$INS644 el.patch $dest/usr/src/$softname-$softversion
)

#> fix permissions
(
chown -R root.root $dest
cd $dest
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(
cd $dest
makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
depfinder $package.txz > $package.dep
echo $sourcetemplate/build-$softname.sh > $package.src
echo $source >> $package.src
echo $sourcetemplate/el.patch >> $package.src

#>
#rm -rf $src
#rm -rf $dest


#> log
) 2>&1 | tee pcmanfm-mod-build.log.txt
